@@ -1,5 +1,5 @@
-/* 
- * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
+/*
+ * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,47 +16,43 @@
  */
 
 #ifndef _VOTCA_CSG_TRAJECTORYREADER_H
-#define	_VOTCA_CSG_TRAJECTORYREADER_H
+#define _VOTCA_CSG_TRAJECTORYREADER_H
 
-#include <string>
-#include "topology.h"
 #include "fileformatfactory.h"
+#include "topology.h"
+#include <string>
 
-namespace votca { namespace csg {
-using namespace votca::tools;
-
-using namespace std;
+namespace votca {
+namespace csg {
 
 /**
     \brief trajectoryreader interface
-    
+
     This class defines the interface a trajectory reader has to implement
  */
-class TrajectoryReader
-{
-public:
-    virtual ~TrajectoryReader() {}
-    /// open a trejectory file
-    virtual bool Open(const string &file) = 0;
-        
-    virtual void Close() {};
-        
-    /// read in the first frame
-    virtual bool FirstFrame(Topology &top) = 0;
-    /// read in the next frame
-    virtual bool NextFrame(Topology &top) = 0;
+class TrajectoryReader {
+ public:
+  virtual ~TrajectoryReader() = default;
+  /// open a trejectory file
+  virtual bool Open(const std::string &file) = 0;
 
-    static void RegisterPlugins(void);
+  virtual void Close(){};
+
+  /// read in the first frame
+  virtual bool FirstFrame(Topology &top) = 0;
+  /// read in the next frame
+  virtual bool NextFrame(Topology &top) = 0;
+
+  static void RegisterPlugins(void);
 };
 
 // important - singleton pattern, make sure factory is created before accessed
-inline FileFormatFactory<TrajectoryReader> &TrjReaderFactory()
-{
-    static FileFormatFactory<TrajectoryReader> _TrjReaderFactory;
-    return _TrjReaderFactory;
+inline FileFormatFactory<TrajectoryReader> &TrjReaderFactory() {
+  static FileFormatFactory<TrajectoryReader> _TrjReaderFactory;
+  return _TrjReaderFactory;
 }
 
-}}
-
-#endif	/* _VOTCA_CSG_TRAJECTORYREADER_H */
+}  // namespace csg
+}  // namespace votca
 
+#endif /* _VOTCA_CSG_TRAJECTORYREADER_H */
