@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,27 +16,25 @@
  */
 
 #ifndef _VOTCA_CSG_TRICLINICBOX_H
-#define	_VOTCA_CSG_TRICLINICBOX_H
+#define _VOTCA_CSG_TRICLINICBOX_H
 
 #include "boundarycondition.h"
 
-namespace votca { namespace csg {
-using namespace std;
-using namespace votca::tools;
+namespace votca {
+namespace csg {
 
 class TriclinicBox : public BoundaryCondition {
 
-public:
-    vec BCShortestConnection(const vec &r_i, const vec &r_j) const;
+ public:
+  Eigen::Vector3d BCShortestConnection(const Eigen::Vector3d &r_i,
+                                       const Eigen::Vector3d &r_j) const final;
 
-    eBoxtype getBoxType() {
-        return typeTriclinic;
-    }
+  eBoxtype getBoxType() final { return typeTriclinic; }
 
-protected:
+ protected:
 };
 
-}}
-
-#endif	/* _VOTCA_CSG_TRICLINICBOX_H */
+}  // namespace csg
+}  // namespace votca
 
+#endif /* _VOTCA_CSG_TRICLINICBOX_H */
