@@ -270,7 +270,7 @@ csg_get_interaction_property () { #gets an interaction property from the xml fil
       for map in ${mapping}; do
         [[ -f "$(get_main_dir)/$map" ]] || die "${FUNCNAME[0]}: Mapping file '$map' for bonded interaction not found in maindir"
 	names+=( $(critical -q csg_property --file "$(get_main_dir)/$map" --path cg_molecule.topology.cg_bonded.*.name --print . --short) )
-	dup=$(has_duplicate "${names[@]}") && die "${FUNCNAME[0]}: cg_bonded name '$dup' appears twice in file(s) $mapping"
+	[[ -n ${names[@]} ]] && dup=$(has_duplicate "${names[@]}") && die "${FUNCNAME[0]}: cg_bonded name '$dup' appears twice in file(s) $mapping"
         ret2="$(critical -q csg_property --file "$(get_main_dir)/$map" --path cg_molecule.topology.cg_bonded.* --filter name="$bondname" --print . --with-path | trim_all)"
         ret2="$(echo "$ret2" | critical sed -n 's/.*cg_bonded\.\([^[:space:]]*\) .*/\1/p')"
 	if [[ -n $ret2 ]]; then
@@ -655,16 +655,14 @@ add_to_csgshare() { #added an directory to the csg internal search directories
       if [[ $end = "yes" ]]; then
         export CSGSHARE="${CSGSHARE}${CSGSHARE:+:}$dir"
         export PERL5LIB="${PERL5LIB}${PERL5LIB:+:}$dir"
-        export PYTHONPATH="${PYTHONPATH}${PYTHONPATH:+:}$dir"
       else
         export CSGSHARE="$dir${CSGSHARE:+:}$CSGSHARE"
         export PERL5LIB="$dir${PERL5LIB:+:}$PERL5LIB"
-        export PYTHONPATH="$dir${PYTHONPATH:+:}$PYTHONPATH"
       fi
     done
     IFS="$old_IFS"
   done
-  check_path_variable CSGSHARE PERL5LIB PYTHONPATH
+  check_path_variable CSGSHARE PERL5LIB
 }
 export -f add_to_csgshare
 
@@ -884,7 +882,8 @@ check_for_obsolete_xml_options() { #check xml file for obsolete options
     cg.inverse.espresso.exclusions cg.inverse.espresso.debug cg.inverse.espresso.n_snapshots \
     cg.non-bonded.inverse.espresso.index1 cg.non-bonded.inverse.espresso.index2 cg.inverse.espresso.success \
     cg.inverse.espresso.scriptdir cg.non-bonded.inverse.post_update_options.kbibi.type \
-    cg.inverse.imc.numpy.bin \
+    cg.inverse.imc.numpy.bin cg.inverse.imc.octave.bin cg.inverse.imc.matlab.bin cg.inverse.imc.solver \
+    cg.non-bonded.inverse.imc.reg \
     ; do
     [[ -z "$(csg_get_property --allow-empty $i)" ]] && continue #filter me away
     new=""
@@ -909,6 +908,8 @@ check_for_obsolete_xml_options() { #check xml file for obsolete options
 	new="${i}.type";;
       cg.inverse.convergence_check_options.limit)
         new="cg.inverse.convergence_check.limit";;
+      cg.non-bonded.inverse.imc.reg)
+        new="cg.inverse.imc.<group>.reg";;
     esac
     [[ -n $new ]] && new="has been renamed to $new" || new="has been removed"
     die "${FUNCNAME[0]}: The xml option $i $new\nPlease remove the obsolete options from the xmlfile"
