@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2015 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,110 +18,126 @@
 #ifndef SRC_LIBCSG_MODULES_IO_H5MDTRAJECTORYREADER_H_
 #define SRC_LIBCSG_MODULES_IO_H5MDTRAJECTORYREADER_H_
 
-#include <votca/csg/trajectoryreader.h>
 #include <votca/csg/topologyreader.h>
+#include <votca/csg/trajectoryreader.h>
 
+#include <cstdio>
 #include <fstream>
 #include <iostream>
 #include <string>
-#include <cstdio>
 
 #include "hdf5.h"
 
 namespace votca {  // NOLINT
 namespace csg {
-using namespace votca::tools;  // NOLINT
 
 /**
     \brief class for reading H5MD trajectory.
 
-    This class implements the H5MD trajectory reading function. The format of the H5MD
-    file is defined in
-    Pierre de Buyl, Peter H. Colberg, Felix Höfling, H5MD: A structured, efficient, and portable file
-    format for molecular data, http://dx.doi.org/10.1016/j.cpc.2014.01.018
-    The current reference is available here: http://nongnu.org/h5md/
+    This class implements the H5MD trajectory reading function. The format of
+   the H5MD file is defined in Pierre de Buyl, Peter H. Colberg, Felix Höfling,
+   H5MD: A structured, efficient, and portable file format for molecular data,
+   http://dx.doi.org/10.1016/j.cpc.2014.01.018 The current reference is
+   available here: http://nongnu.org/h5md/
 */
 class H5MDTrajectoryReader : public TrajectoryReader {
  public:
   H5MDTrajectoryReader();
-  ~H5MDTrajectoryReader();
+  ~H5MDTrajectoryReader() override;
 
   /// Opens original trajectory file.
-  bool Open(const string &file);
+  bool Open(const std::string &file) override;
 
   /// Initialize data structures.
   void Initialize(Topology &top);
 
   /// Reads in the first frame.
-  bool FirstFrame(Topology &conf);  // NOLINT
+  bool FirstFrame(Topology &conf) override;
 
   /// Reads in the next frame.
-  bool NextFrame(Topology &conf);  // NOLINT
+  bool NextFrame(Topology &conf) override;
 
   /// Closes original trajectory file.
-  void Close();
+  void Close() override;
 
  private:
   enum DatasetState { NONE, STATIC, TIMEDEPENDENT };
 
   /// Reads dataset that contains vectors.
   template <typename T1>
-  T1* ReadVectorData(hid_t ds, hid_t ds_data_type, int row) {
-    hsize_t offset[3]; offset[0] = row; offset[1] = 0; offset[2] = 0;
-    hsize_t chunk_rows[3]; chunk_rows[0] = 1; chunk_rows[1] = N_particles_; chunk_rows[2] = vec_components_;
+  T1 *ReadVectorData(hid_t ds, hid_t ds_data_type, Index row) {
+    hsize_t offset[3];
+    offset[0] = hsize_t(row);
+    offset[1] = 0;
+    offset[2] = 0;
+    hsize_t chunk_rows[3];
+    chunk_rows[0] = 1;
+    chunk_rows[1] = N_particles_;
+    chunk_rows[2] = vec_components_;
     hid_t dsp = H5Dget_space(ds);
-    H5Sselect_hyperslab(dsp, H5S_SELECT_SET, offset, NULL, chunk_rows, NULL);
-    hid_t mspace1 = H5Screate_simple(vec_components_, chunk_rows, NULL);
+    H5Sselect_hyperslab(dsp, H5S_SELECT_SET, offset, nullptr, chunk_rows,
+                        nullptr);
+    hid_t mspace1 = H5Screate_simple(vec_components_, chunk_rows, nullptr);
     T1 *data_out = new T1[N_particles_ * vec_components_];
-    herr_t status = H5Dread(ds, ds_data_type, mspace1, dsp, H5P_DEFAULT, data_out);
+    herr_t status =
+        H5Dread(ds, ds_data_type, mspace1, dsp, H5P_DEFAULT, data_out);
     if (status < 0) {
-      throw std::runtime_error("Error ReadVectorData: " + boost::lexical_cast<string>(status));
-    } else
-      return data_out;
-  }
-
-  /// Reads dataset with scalar values.
-  template <typename T1>
-  T1* ReadScalarData(hid_t ds, hid_t ds_data_type, int row) {
-    hsize_t offset[2]; offset[0] = row; offset[1] = 0;
-    hsize_t ch_rows[2]; ch_rows[0] = 1; ch_rows[1] = N_particles_;
-    hid_t dsp = H5Dget_space(ds);
-    H5Sselect_hyperslab(dsp, H5S_SELECT_SET, offset, NULL, ch_rows, NULL);
-    hid_t mspace1 = H5Screate_simple(2, ch_rows, NULL);
-    T1 *data_out = new T1[N_particles_];
-    herr_t status = H5Dread(ds, ds_data_type, mspace1, dsp, H5P_DEFAULT, data_out);
-    if (status < 0) {
-      throw std::runtime_error("Error ReadScalarData: " + boost::lexical_cast<string>(status));
+      throw std::runtime_error("Error ReadVectorData: " +
+                               boost::lexical_cast<std::string>(status));
     } else {
       return data_out;
     }
   }
 
-  template<typename T1>
-  void ReadStaticData(hid_t ds, hid_t ds_data_type, T1 &outbuf) {
-    herr_t status = H5Dread(
-        ds,
-        ds_data_type,
-        H5S_ALL,
-        H5S_ALL,
-        H5P_DEFAULT, outbuf);
+  /// Reads dataset with scalar values.
+  template <typename T1>
+  T1 *ReadScalarData(hid_t ds, hid_t ds_data_type, Index row) {
+    hsize_t offset[2];
+    offset[0] = row;
+    offset[1] = 0;
+    hsize_t ch_rows[2];
+    ch_rows[0] = 1;
+    ch_rows[1] = N_particles_;
+    hid_t dsp = H5Dget_space(ds);
+    H5Sselect_hyperslab(dsp, H5S_SELECT_SET, offset, nullptr, ch_rows, nullptr);
+    hid_t mspace1 = H5Screate_simple(2, ch_rows, nullptr);
+    T1 *data_out = new T1[N_particles_];
+    herr_t status =
+        H5Dread(ds, ds_data_type, mspace1, dsp, H5P_DEFAULT, data_out);
+    if (status < 0) {
+      throw std::runtime_error("Error ReadScalarData: " +
+                               boost::lexical_cast<std::string>(status));
+    } else {
+      return data_out;
+    }
+  }
+
+  template <typename T1>
+  void ReadStaticData(hid_t ds, hid_t ds_data_type,
+                      std::unique_ptr<T1> &outbuf) {
+    herr_t status =
+        H5Dread(ds, ds_data_type, H5S_ALL, H5S_ALL, H5P_DEFAULT, outbuf.get());
     if (status < 0) {
       H5Eprint(H5E_DEFAULT, stderr);
     }
   }
 
+  void ReadBox(hid_t ds, hid_t ds_data_type, Index row,
+               std::unique_ptr<double[]> &data_out);
+
   void CheckError(hid_t hid, std::string error_message) {
     if (hid < 0) {
-      //H5Eprint(H5E_DEFAULT, stderr);
+      // H5Eprint(H5E_DEFAULT, stderr);
       throw std::runtime_error(error_message);
     }
   }
 
   bool GroupExists(hid_t file_id, std::string path) {
     H5G_stat_t info;
-    herr_t status = H5Gget_objinfo (file_id, path.c_str(), 0, &info);
-    if (status < 0)
+    herr_t status = H5Gget_objinfo(file_id, path.c_str(), 0, &info);
+    if (status < 0) {
       return false;
+    }
     return info.type == H5G_GROUP;
   }
 
@@ -139,9 +155,9 @@ class H5MDTrajectoryReader : public TrajectoryReader {
   hid_t atom_id_group_;
   hid_t edges_group_;
 
-  int rank_;
+  Index rank_;
 
-  string fname_;
+  std::string fname_;
   bool first_frame_;
 
   // Flags about datasets.
@@ -153,19 +169,19 @@ class H5MDTrajectoryReader : public TrajectoryReader {
   bool file_opened_;
 
   // Current frame indicator.
-  int idx_frame_;
-  int max_idx_frame_;
+  Index idx_frame_;
+  Index max_idx_frame_;
 
   // Number of particles. This is static among time.
-  int N_particles_;
+  Index N_particles_;
   //
   int vec_components_;
 
   // Box matrix.
-  matrix m;
+  Eigen::Matrix3d m;
 };
 
 }  // namespace csg
-}  // namespace votca  // NOLINT
+}  // namespace votca
 
 #endif  // SRC_LIBCSG_MODULES_IO_H5MDTRAJECTORYREADER_H_
