@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,10 +17,11 @@
 
 #include <votca/csg/triclinicbox.h>
 
-namespace votca { namespace csg {
+namespace votca {
+namespace csg {
 
 /*
- This way of determining the shortest distance is only working for a set of 
+ This way of determining the shortest distance is only working for a set of
  triclinic boxes, in particular
  a_y = a_z = b_z = 0
  a_x > 0, b_y > 0, c_z > 0
@@ -29,15 +30,13 @@ namespace votca { namespace csg {
  If a simple search algorithm is used to determine if a particle
  is a within cutoff r_c, make sure that r_c < 0.5 min(a_x, b_y, c_z)
  */
-vec TriclinicBox::BCShortestConnection(const vec &r_i, const vec &r_j) const
-{
-    vec r_tp, r_dp, r_sp, r_ij;
-    vec a = _box.getCol(0); vec b = _box.getCol(1); vec c = _box.getCol(2);
-    r_tp = r_j - r_i;
-    r_dp = r_tp - c*round(r_tp.getZ()/c.getZ());
-    r_sp = r_dp - b*round(r_dp.getY()/b.getY());
-    r_ij = r_sp - a*round(r_sp.getX()/a.getX());
-    return r_ij;
+Eigen::Vector3d TriclinicBox::BCShortestConnection(
+    const Eigen::Vector3d &r_i, const Eigen::Vector3d &r_j) const {
+  Eigen::Vector3d r_tp = r_j - r_i;
+  Eigen::Vector3d r_dp = r_tp - _box.col(2) * std::round(r_tp.z() / _box(2, 2));
+  Eigen::Vector3d r_sp = r_dp - _box.col(1) * std::round(r_dp.y() / _box(1, 1));
+  return r_sp - _box.col(0) * std::round(r_sp.x() / _box(0, 0));
 }
 
-}}
+}  // namespace csg
+}  // namespace votca
